@@ -3,3 +3,6 @@ __date__ = '10/5/12'
 
 MAILQUEUE_CELERY = False
 MAILQUEUE_LIMIT = 30
+MAILQUEUE_QUEUE_UP = False
+MAILQUEUE_CLEAR_OFFSET = 0
+
